==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGridToolbarBaseActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebGridToolbarBaseActionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarBaseActionDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarBaseActionDescriptionMetadata.a == null) {
                WebGridToolbarBaseActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarBaseActionDescriptionMetadata.c(WebGridToolbarBaseActionDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarBaseActionDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridToolbarBaseActionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridToolbarBaseAction");
            a.item("__tagNameWC", "String:igc-grid-toolbar-base-action");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("Name", "String");
            WebGridToolbarBaseActionDescriptionMetadata.e(a);
        }
        static d(a) {
            WebGridToolbarBaseActionDescriptionMetadata.b(a);
            a.ac("WebGridToolbarBaseAction", WebGridToolbarBaseActionDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__tagNameWCSubstitutable", "String:igc-grid-toolbar-advanced-filtering,igc-grid-toolbar-exporter,igc-grid-toolbar-hiding,igc-grid-toolbar-pinning");
        }
    }
    WebGridToolbarBaseActionDescriptionMetadata.$t = markType(WebGridToolbarBaseActionDescriptionMetadata, 'WebGridToolbarBaseActionDescriptionMetadata');
    WebGridToolbarBaseActionDescriptionMetadata.a = null;
    return WebGridToolbarBaseActionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGridToolbarBaseActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebGridToolbarBaseActionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarBaseActionDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarBaseActionDescriptionMetadata.a == null) {
                WebGridToolbarBaseActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarBaseActionDescriptionMetadata.c(WebGridToolbarBaseActionDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarBaseActionDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridToolbarBaseActionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridToolbarBaseAction");
            a.item("__tagNameWC", "String:igc-grid-toolbar-base-action");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("Name", "String");
            WebGridToolbarBaseActionDescriptionMetadata.e(a);
        }
        static d(a) {
            WebGridToolbarBaseActionDescriptionMetadata.b(a);
            a.ad("WebGridToolbarBaseAction", WebGridToolbarBaseActionDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__tagNameWCSubstitutable", "String:igc-grid-toolbar-advanced-filtering,igc-grid-toolbar-exporter,igc-grid-toolbar-hiding,igc-grid-toolbar-pinning");
        }
    }
    WebGridToolbarBaseActionDescriptionMetadata.$t = markType(WebGridToolbarBaseActionDescriptionMetadata, 'WebGridToolbarBaseActionDescriptionMetadata');
    WebGridToolbarBaseActionDescriptionMetadata.a = null;
    return WebGridToolbarBaseActionDescriptionMetadata;
})();
